@@ -15,13 +15,19 @@ use Convert::Wiki::Node;
 use vars qw/$VERSION @ISA/;
 
 @ISA = qw/Convert::Wiki::Node/;
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 #############################################################################
 
-sub as_wiki
+sub _init
   {
-  "----\n\n";
+  my ($self,$args) = @_;
+
+  $self->SUPER::_init($args);
+
+  $self->{txt} = "----\n\n";
+
+  $self;
   }
 
 sub _remove_me
